@@ -12,9 +12,7 @@ from mptt.admin import MPTTModelAdmin
 
 
 class NodeTypeChoiceForm(PolymorphicModelChoiceForm):
-    def __init__(self, *args, **kwargs):
-        super(NodeTypeChoiceForm, self).__init__(*args, **kwargs)
-        self.fields['ct_id'].label = _("Node type")
+    type_label = _("Node type")
 
 
 try:
@@ -78,8 +76,7 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         Return a list of all action icons in the :func:`actions_column`.
         """
         actions = []
-        NodeClass = node.get_real_instance_class()   # Avoid need for upcasted model.
-        if NodeClass.can_have_children:
+        if self.can_have_children(node):
             actions.append(
                 u'<a href="add/?{parent_attr}={id}" title="{title}"><img src="{static}polymorphic_tree/icons/page_new.gif" width="16" height="16" alt="{title}" /></a>'.format(
                     parent_attr=self.model._mptt_meta.parent_attr, id=node.pk, title=_('Add sub node'), static=settings.STATIC_URL)
@@ -87,7 +84,7 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         else:
             actions.append(self.EMPTY_ACTION_ICON)
 
-        if hasattr(node, 'get_absolute_url'):
+        if self.can_preview_object(node):
             actions.append(
                 u'<a href="{url}" title="{title}" target="_blank"><img src="{static}polymorphic_tree/icons/world.gif" width="16" height="16" alt="{title}" /></a>'.format(
                     url=node.get_absolute_url(), title=_('View on site'), static=settings.STATIC_URL)
@@ -100,6 +97,27 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         return actions
 
 
+    def can_preview_object(self, node):
+        """
+        Define whether a node can be previewed.
+        """
+        return hasattr(node, 'get_absolute_url')
+
+
+    def can_have_children(self, node):
+        """
+        Define whether a node can have children.
+        """
+        # Allow can_have_children to be either to be a property on the base class that always works.
+        if not node.can_have_children:
+            return False
+
+        # or a static variable declared on the class (avoids need for upcasted models).
+        NodeClass = node.get_real_instance_class()
+        return bool(NodeClass.can_have_children)
+
+
+
     # ---- Custom views ----
 
     def get_urls(self):
@@ -139,8 +157,7 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         except self.model.DoesNotExist as e:
             return HttpResponseNotFound(simplejson.dumps({'action': 'reload', 'error': str(e[0])}), content_type='application/json')
 
-        TargetClass = target.get_real_instance_class()
-        if not TargetClass.can_have_children and position == 'inside':
+        if not self.can_have_children(target) and position == 'inside':
             return HttpResponse(simplejson.dumps({'action': 'reject', 'error': 'Cannot move inside target, does not allow children!'}), content_type='application/json', status=409)  # Conflict
         if moved.parent_id != previous_parent_id:
             return HttpResponse(simplejson.dumps({'action': 'reload', 'error': 'Client seems to be out-of-sync, please reload!'}), content_type='application/json', status=409)
